@@ -96,6 +96,10 @@ class ClBuilderUpdateAction(Action):
                 {'name': 'clear_log',
                  'method': 'Builder.clear_log(cl_builder_id_path)',
                  },
+                {'name': 'modify_binary_depends',
+                 'method': 'Builder.modify_binary_depends('
+                           'builder.cl_builder_with_bdeps_opt_set,builder.cl_builder_path)'
+                },
                 {'name': 'allow_scan_binhost',
                  'method': 'Builder.setVariable("cl_builder_binhost_scan_set",'
                            '"on",True)'
